@@ -82,13 +82,9 @@ def _validate_float_range(float_min, float_max, *field_names):
 def _validate_float_none(*field_names):
     @validates(*field_names)
     def is_float_none(self, key, value):
-        try:
-            return float(value)
-        except ValueError:
-            if value is None or value == "":
-                return None
-            else:
-                raise
+        if value is None or value == "":
+            return None
+        return float(value)
     return is_float_none
 
 
@@ -361,10 +357,10 @@ class StopTime(Base):
     __tablename__ = 'stop_times'
     _plural_name_ = 'stop_times'
     feed_id = Column(Integer, ForeignKey('_feed.feed_id'), primary_key=True)
-    trip_id = Column(Unicode, primary_key=True)
+    trip_id = Column(Unicode, primary_key=True, index=True)
     arrival_time = Column(Interval)
     departure_time = Column(Interval)
-    stop_id = Column(Unicode, primary_key=True)
+    stop_id = Column(Unicode, primary_key=True, index=True)
     stop_sequence = Column(Integer, primary_key=True)
     stop_headsign = Column(Unicode)
     pickup_type = Column(Integer)
